# Notes on generating libsba.so

  1. To obtain libsba, download sba-1.6.1.tgz from the original Lourakis sba library at [http://www.ics.forth.gr/~lourakis/sba]. Unzip the contents and change to directory containing them; we will build here. 

  2. Copy the Makefile.example file to the build directory and rename it Makefile.  You will use the ```make``` command to build libsba.so. 

  3. Follow the install directions (as administrator). For details see HOWTO.md in the main python-sba directory. 

